from ..error import CwsError


class CwsClientError(CwsError):
    pass


class CwsCommandError(CwsError):
    pass
